@@ -159,6 +159,23 @@ bool MaybeDisabledEmoji::readyInDefaultState() {
 	return { Data::ReactionId{ like }, Data::ReactionId{ dislike } };
 }
 
+[[nodiscard]] std::vector<Data::ReactionId> CollectAvailableReactions(
+		not_null<Main::Session*> session) {
+	const auto &all = session->data().reactions().list(
+		Data::Reactions::Type::Active);
+	if (all.empty()) {
+		return DefaultSelected();
+	}
+	auto result = std::vector<Data::ReactionId>();
+	result.reserve(all.size());
+	for (const auto &reaction : all) {
+		if (!reaction.id.paid()) {
+			result.push_back(reaction.id);
+		}
+	}
+	return result;
+}
+
 [[nodiscard]] bool RemoveNonCustomEmojiFragment(
 		not_null<QTextDocument*> document,
 		UniqueCustomEmojiContext &context) {
@@ -235,7 +252,7 @@ void SetupOnlyCustomEmojiField(
 	const auto state = field->lifetime().make_state<State>();
 
 	field->changes(
-	) | rpl::start_with_next([=] {
+	) | rpl::on_next([=] {
 		state->pending = true;
 		if (state->processing) {
 			return;
@@ -323,6 +340,7 @@ struct ReactionsSelectorArgs {
 	int customAllowed = 0;
 	int customHardLimit = 0;
 	bool all = false;
+	bool isGroup = false;
 };
 
 object_ptr<Ui::RpWidget> AddReactionsSelector(
@@ -420,7 +438,7 @@ object_ptr<Ui::RpWidget> AddReactionsSelector(
 	applyFromState();
 	std::move(
 		args.paid
-	) | rpl::start_with_next([=](bool paid) {
+	) | rpl::on_next([=](bool paid) {
 		const auto id = Data::ReactionId::Paid();
 		if (paid && !ranges::contains(state->reactions, id)) {
 			state->reactions.insert(begin(state->reactions), id);
@@ -440,14 +458,19 @@ object_ptr<Ui::RpWidget> AddReactionsSelector(
 	using SelectorState = ReactionsSelectorState;
 	std::move(
 		args.stateValue
-	) | rpl::start_with_next([=](SelectorState value) {
+	) | rpl::on_next([=, all = args.all](SelectorState value) {
 		switch (value) {
 		case SelectorState::Active:
 			state->overlay = nullptr;
 			state->focusLifetime.destroy();
 			if (raw->empty()) {
 				raw->setTextWithTags(
-					ComposeEmojiList(reactions, DefaultSelected()));
+					ComposeEmojiList(
+						reactions,
+						all
+							? CollectAvailableReactions(
+								&args.controller->session())
+							: DefaultSelected()));
 			}
 			raw->setDisabled(false);
 			raw->setFocusFast();
@@ -455,10 +478,10 @@ object_ptr<Ui::RpWidget> AddReactionsSelector(
 		case SelectorState::Disabled:
 			state->overlay = std::make_unique<Ui::RpWidget>(parent);
 			state->overlay->show();
-			raw->geometryValue() | rpl::start_with_next([=](QRect rect) {
+			raw->geometryValue() | rpl::on_next([=](QRect rect) {
 				state->overlay->setGeometry(rect);
 			}, state->overlay->lifetime());
-			state->overlay->paintRequest() | rpl::start_with_next([=](QRect clip) {
+			state->overlay->paintRequest() | rpl::on_next([=](QRect clip) {
 				auto color = st::boxBg->c;
 				color.setAlphaF(0.5);
 				QPainter(state->overlay.get()).fillRect(
@@ -472,7 +495,7 @@ object_ptr<Ui::RpWidget> AddReactionsSelector(
 			}
 			raw->setDisabled(true);
 			raw->focusedChanges(
-			) | rpl::start_with_next([=](bool focused) {
+			) | rpl::on_next([=](bool focused) {
 				if (focused) {
 					raw->parentWidget()->setFocus();
 				}
@@ -503,7 +526,7 @@ object_ptr<Ui::RpWidget> AddReactionsSelector(
 		st::emojiPanMinHeight);
 	panel->hide();
 	panel->selector()->customEmojiChosen(
-	) | rpl::start_with_next([=](ChatHelpers::FileChosen data) {
+	) | rpl::on_next([=](ChatHelpers::FileChosen data) {
 		Data::InsertCustomEmoji(raw, data.document);
 	}, panel->lifetime());
 
@@ -540,7 +563,7 @@ object_ptr<Ui::RpWidget> AddReactionsSelector(
 		panel->toggleAnimated();
 	});
 
-	raw->geometryValue() | rpl::start_with_next([=](QRect geometry) {
+	raw->geometryValue() | rpl::on_next([=](QRect geometry) {
 		toggle->move(
 			geometry.x() + geometry.width() - toggle->width(),
 			geometry.y() + geometry.height() - toggle->height());
@@ -572,9 +595,8 @@ void AddReactionsText(
 			inner,
 			tr::lng_manage_peer_reactions_own(
 				lt_link,
-				tr::lng_manage_peer_reactions_own_link(
-				) | Ui::Text::ToLink(),
-				Ui::Text::WithEntities),
+				tr::lng_manage_peer_reactions_own_link(tr::link),
+				tr::marked),
 			st::boxDividerLabel));
 	const auto weak = base::make_weak(navigation);
 	label->setClickHandlerFilter([=](const auto &...) {
@@ -595,11 +617,11 @@ void AddReactionsText(
 			count->value() | tr::to_count(),
 			lt_same_count,
 			std::move(countString),
-			Ui::Text::RichLangValue),
+			tr::rich),
 		tr::lng_manage_peer_reactions_boost(
 			lt_link,
-			tr::lng_manage_peer_reactions_boost_link() | Ui::Text::ToLink(),
-			Ui::Text::RichLangValue)
+			tr::lng_manage_peer_reactions_boost_link(tr::link),
+			tr::rich)
 	) | rpl::map([](TextWithEntities &&a, TextWithEntities &&b) {
 		a.append(' ').append(std::move(b));
 		return std::move(a);
@@ -669,7 +691,7 @@ void EditAllowedReactionsBox(
 	if (enabled) {
 		enabled->toggleOn(rpl::single(optionInitial != Option::None));
 		enabled->toggledValue(
-		) | rpl::start_with_next([=](bool value) {
+		) | rpl::on_next([=](bool value) {
 			state->selectorState = value
 				? SelectorState::Active
 				: SelectorState::Disabled;
@@ -737,9 +759,7 @@ void EditAllowedReactionsBox(
 
 	const auto all = args.list;
 	auto selected = (allowed.type != AllowedReactionsType::Some)
-		? (all
-			| ranges::views::transform(&Data::Reaction::id)
-			| ranges::to_vector)
+		? std::vector<Data::ReactionId>()
 		: allowed.some;
 	if (allowed.paidEnabled) {
 		selected.insert(begin(selected), Data::ReactionId::Paid());
@@ -759,7 +779,14 @@ void EditAllowedReactionsBox(
 				tr::lng_manage_peer_reactions_limit(tr::now));
 		}
 	};
-	changed(selected.empty() ? DefaultSelected() : std::move(selected), {});
+	changed(
+		!selected.empty()
+			? std::move(selected)
+			: !isGroup
+			? CollectAvailableReactions(
+				&args.navigation->parentController()->session())
+			: DefaultSelected(),
+		{});
 	Ui::AddSubsectionTitle(
 		reactions,
 		enabled
@@ -836,7 +863,7 @@ void EditAllowedReactionsBox(
 			left->sizeValue(),
 			center->sizeValue(),
 			right->sizeValue()
-		) | rpl::start_with_next([=](
+		) | rpl::on_next([=](
 				const QSize &s,
 				const QSize &leftSize,
 				const QSize &centerSize,
@@ -901,7 +928,7 @@ void EditAllowedReactionsBox(
 			st::manageGroupNoIconButton.button));
 		paid->toggleOn(state->paidEnabled.value());
 		paid->toggledValue(
-		) | rpl::start_with_next([=](bool value) {
+		) | rpl::on_next([=](bool value) {
 			state->paidEnabled = value;
 		}, paid->lifetime());
 		Ui::AddSkip(inner);
@@ -911,11 +938,11 @@ void EditAllowedReactionsBox(
 			tr::lng_manage_peer_reactions_paid_about(
 				lt_link,
 				tr::lng_manage_peer_reactions_paid_link([=](QString text) {
-					return Ui::Text::Link(
+					return tr::link(
 						text,
 						u"https://telegram.org/tos/stars"_q);
 				}),
-				Ui::Text::WithEntities));
+				tr::marked));
 	}
 	const auto collect = [=] {
 		auto result = AllowedReactions();
@@ -986,7 +1013,7 @@ void SaveAllowedReactions(
 		MTP_flags(Flag()
 			| (maxCount ? Flag::f_reactions_limit : Flag())
 			| (editPaidEnabled ? Flag::f_paid_enabled : Flag())),
-		peer->input,
+		peer->input(),
 		updated,
 		MTP_int(maxCount),
 		MTP_bool(paidEnabled)
