@@ -70,6 +70,7 @@ struct UniqueGiftCoverArgs {
 	rpl::producer<TextWithEntities> subtitle;
 	Fn<void()> subtitleClick;
 	bool subtitleLinkColored = false;
+	bool subtitleOutlined = false;
 	rpl::producer<CreditsAmount> resalePrice;
 	Fn<void()> resaleClick;
 	bool attributesInfo = false;
@@ -94,6 +95,12 @@ void AddWearGiftCover(
 	const Data::UniqueGift &data,
 	not_null<PeerData*> peer);
 
+void AttachGiftSenderBadge(
+	not_null<GenericBox*> box,
+	std::shared_ptr<ChatHelpers::Show> show,
+	not_null<PeerData*> from,
+	const QDateTime &date);
+
 void ShowUniqueGiftWearBox(
 	std::shared_ptr<ChatHelpers::Show> show,
 	not_null<PeerData*> peer,
@@ -135,11 +142,6 @@ struct StarGiftUpgradeArgs {
 };
 void ShowStarGiftUpgradeBox(StarGiftUpgradeArgs &&args);
 
-void AddUniqueCloseButton(
-	not_null<GenericBox*> box,
-	Settings::CreditsEntryBoxStyleOverrides st,
-	Fn<void(not_null<PopupMenu*>)> fillMenu = nullptr);
-
 void SubmitStarsForm(
 	std::shared_ptr<Main::SessionShow> show,
 	MTPInputInvoice invoice,
