@@ -36,7 +36,7 @@ namespace {
 class JoinAsAction final : public Ui::Menu::ItemBase {
 public:
 	JoinAsAction(
-		not_null<Ui::RpWidget*> parent,
+		not_null<Ui::Menu::Menu*> parent,
 		const style::Menu &st,
 		not_null<PeerData*> peer,
 		Fn<void()> callback);
@@ -72,7 +72,7 @@ private:
 class RecordingAction final : public Ui::Menu::ItemBase {
 public:
 	RecordingAction(
-		not_null<Ui::RpWidget*> parent,
+		not_null<Ui::Menu::Menu*> parent,
 		const style::Menu &st,
 		rpl::producer<QString> text,
 		rpl::producer<TimeId> startAtValues,
@@ -116,7 +116,7 @@ TextParseOptions MenuTextOptions = {
 };
 
 JoinAsAction::JoinAsAction(
-	not_null<Ui::RpWidget*> parent,
+	not_null<Ui::Menu::Menu*> parent,
 	const style::Menu &st,
 	not_null<PeerData*> peer,
 	Fn<void()> callback)
@@ -128,8 +128,8 @@ JoinAsAction::JoinAsAction(
 	+ st::groupCallJoinAsPhotoSize
 	+ st::groupCallJoinAsPadding.bottom()) {
 	setAcceptBoth(true);
-	initResizeHook(parent->sizeValue());
-	setClickedCallback(std::move(callback));
+	fitToMenuWidth();
+	setActionTriggered(std::move(callback));
 
 	paintRequest(
 	) | rpl::on_next([=] {
@@ -235,7 +235,7 @@ void JoinAsAction::handleKeyPress(not_null<QKeyEvent*> e) {
 }
 
 RecordingAction::RecordingAction(
-	not_null<Ui::RpWidget*> parent,
+	not_null<Ui::Menu::Menu*> parent,
 	const style::Menu &st,
 	rpl::producer<QString> text,
 	rpl::producer<TimeId> startAtValues,
@@ -262,8 +262,8 @@ RecordingAction::RecordingAction(
 	}, lifetime());
 
 	setAcceptBoth(true);
-	initResizeHook(parent->sizeValue());
-	setClickedCallback(std::move(callback));
+	fitToMenuWidth();
+	setActionTriggered(std::move(callback));
 
 	paintRequest(
 	) | rpl::on_next([=] {
