@@ -970,7 +970,7 @@ void Uploader::uploadCoverAsPhoto(
 	_api->request(MTPmessages_UploadMedia(
 		MTP_flags(0),
 		MTPstring(), // business_connection_id
-		session().data().peer(videoId.peer)->input,
+		session().data().peer(videoId.peer)->input(),
 		MTP_inputMediaUploadedPhoto(
 			MTP_flags(0),
 			cover.info.file,
