@@ -207,14 +207,13 @@ Action::Action(
 , _height(st::defaultWhoRead.itemPadding.top()
 		+ _st.itemStyle.font->height
 		+ st::defaultWhoRead.itemPadding.bottom()) {
-	const auto parent = parentMenu->menu();
 	const auto delay = anim::Disabled() ? 0 : parentMenu->st().duration;
 	const auto checkAppeared = [=, now = crl::now()](bool force = false) {
 		_appeared = force || ((crl::now() - now) >= delay);
 	};
 
 	setAcceptBoth(true);
-	initResizeHook(parent->sizeValue());
+	fitToMenuWidth();
 
 	std::move(
 		content
@@ -516,10 +515,8 @@ WhenAction::WhenAction(
 , _height(st::whenReadPadding.top()
 		+ st::whenReadStyle.font->height
 		+ st::whenReadPadding.bottom()) {
-	const auto parent = parentMenu->menu();
-
 	setAcceptBoth(true);
-	initResizeHook(parent->sizeValue());
+	fitToMenuWidth();
 
 	std::move(
 		content
@@ -724,7 +721,7 @@ int WhenAction::contentHeight() const {
 } // namespace
 
 WhoReactedEntryAction::WhoReactedEntryAction(
-	not_null<RpWidget*> parent,
+	not_null<Ui::Menu::Menu*> parent,
 	CustomEmojiFactory customEmojiFactory,
 	const style::Menu &st,
 	Data &&data)
@@ -735,7 +732,7 @@ WhoReactedEntryAction::WhoReactedEntryAction(
 , _height(st::defaultWhoRead.photoSkip * 2 + st::defaultWhoRead.photoSize) {
 	setAcceptBoth(true);
 
-	initResizeHook(parent->sizeValue());
+	fitToMenuWidth();
 	setData(std::move(data));
 
 	paintRequest(
@@ -759,7 +756,7 @@ int WhoReactedEntryAction::contentHeight() const {
 }
 
 void WhoReactedEntryAction::setData(Data &&data) {
-	setClickedCallback(std::move(data.callback));
+	setActionTriggered(std::move(data.callback));
 	_userpic = std::move(data.userpic);
 	_text.setMarkedText(_st.itemStyle, { data.text }, MenuTextOptions);
 	if (data.date.isEmpty()) {
